==> OOo_2.0.0_Win32Intel_solver_curvirgo_other.zip: solver/680/wntmsci10.pro/inc/com/sun/star/bridge/oleautomation/NamedArgument.hpp <==
#ifndef _COM_SUN_STAR_BRIDGE_OLEAUTOMATION_NAMEDARGUMENT_HPP_
#define _COM_SUN_STAR_BRIDGE_OLEAUTOMATION_NAMEDARGUMENT_HPP_

#ifndef _SAL_CONFIG_H_
#include "sal/config.h"
#endif

#ifndef _COM_SUN_STAR_BRIDGE_OLEAUTOMATION_NAMEDARGUMENT_HDL_
#include "com/sun/star/bridge/oleautomation/NamedArgument.hdl"
#endif

#ifndef _COM_SUN_STAR_UNO_ANY_HXX_
#include "com/sun/star/uno/Any.hxx"
#endif
#ifndef _COM_SUN_STAR_UNO_TYPE_HXX_
#include "com/sun/star/uno/Type.hxx"
#endif
#ifndef _RTL_USTRING_HXX_
#include "rtl/ustring.hxx"
#endif
#ifndef _SAL_TYPES_H_
#include "sal/types.h"
#endif
#ifndef _TYPELIB_TYPECLASS_H_
#include "typelib/typeclass.h"
#endif
#ifndef _TYPELIB_TYPEDESCRIPTION_H_
#include "typelib/typedescription.h"
#endif

namespace com { namespace sun { namespace star { namespace bridge { namespace oleautomation {

inline NamedArgument::NamedArgument() SAL_THROW( () )
    : Name()
    , Value()
{
}

inline NamedArgument::NamedArgument(const ::rtl::OUString& Name_, const ::com::sun::star::uno::Any& Value_) SAL_THROW( () )
    : Name(Name_)
    , Value(Value_)
{
}

} } } } }

inline ::com::sun::star::uno::Type const & SAL_CALL getCppuType(::com::sun::star::bridge::oleautomation::NamedArgument const *) {
    //TODO: On certain platforms with weak memory models, the following code can result in some threads observing that the_type points to garbage
    static ::typelib_TypeDescriptionReference * the_type = 0;
    if (the_type == 0) {
        ::typelib_static_type_init(&the_type, typelib_TypeClass_STRUCT, "com.sun.star.bridge.oleautomation.NamedArgument");
    }
    return *reinterpret_cast< ::com::sun::star::uno::Type * >(&the_type);
}

#endif // _COM_SUN_STAR_BRIDGE_OLEAUTOMATION_NAMEDARGUMENT_HPP_

==> OOo_2.0.3_Win32Intel_solver_curvirgo_other.zip: solver/680/wntmsci10.pro/inc/com/sun/star/bridge/oleautomation/NamedArgument.hpp <==
#ifndef _COM_SUN_STAR_BRIDGE_OLEAUTOMATION_NAMEDARGUMENT_HPP_
#define _COM_SUN_STAR_BRIDGE_OLEAUTOMATION_NAMEDARGUMENT_HPP_

#ifndef _SAL_CONFIG_H_
#include "sal/config.h"
#endif

#ifndef _COM_SUN_STAR_BRIDGE_OLEAUTOMATION_NAMEDARGUMENT_HDL_
#include "com/sun/star/bridge/oleautomation/NamedArgument.hdl"
#endif

#ifndef _COM_SUN_STAR_UNO_ANY_HXX_
#include "com/sun/star/uno/Any.hxx"
#endif
#ifndef _COM_SUN_STAR_UNO_TYPE_HXX_
#include "com/sun/star/uno/Type.hxx"
#endif
#ifndef INCLUDED_CPPU_UNOTYPE_HXX
#include "cppu/unotype.hxx"
#endif
#ifndef _RTL_USTRING_HXX_
#include "rtl/ustring.hxx"
#endif
#ifndef _SAL_TYPES_H_
#include "sal/types.h"
#endif
#ifndef _TYPELIB_TYPECLASS_H_
#include "typelib/typeclass.h"
#endif
#ifndef _TYPELIB_TYPEDESCRIPTION_H_
#include "typelib/typedescription.h"
#endif

namespace com { namespace sun { namespace star { namespace bridge { namespace oleautomation {

inline NamedArgument::NamedArgument() SAL_THROW( () )
    : Name()
    , Value()
{
}

inline NamedArgument::NamedArgument(const ::rtl::OUString& Name_, const ::com::sun::star::uno::Any& Value_) SAL_THROW( () )
    : Name(Name_)
    , Value(Value_)
{
}

} } } } }

namespace com { namespace sun { namespace star { namespace bridge { namespace oleautomation {

inline ::com::sun::star::uno::Type const & cppu_detail_getUnoType(::com::sun::star::bridge::oleautomation::NamedArgument const *) {
    //TODO: On certain platforms with weak memory models, the following code can result in some threads observing that the_type points to garbage
    static ::typelib_TypeDescriptionReference * the_type = 0;
    if (the_type == 0) {
        ::typelib_static_type_init(&the_type, typelib_TypeClass_STRUCT, "com.sun.star.bridge.oleautomation.NamedArgument");
    }
    return *reinterpret_cast< ::com::sun::star::uno::Type * >(&the_type);
};

} } } } }

inline ::com::sun::star::uno::Type const & SAL_CALL getCppuType(::com::sun::star::bridge::oleautomation::NamedArgument const *) SAL_THROW(()) {
    return ::cppu::UnoType< ::com::sun::star::bridge::oleautomation::NamedArgument >::get();
}

#endif // _COM_SUN_STAR_BRIDGE_OLEAUTOMATION_NAMEDARGUMENT_HPP_
